cmoncrawl.processor.pipeline.router.IRouter.\_\_init\_\_
========================================================

.. currentmodule:: cmoncrawl.processor.pipeline.router

.. automethod:: IRouter.__init__